==> haskell-hie-bios-0.12.0-150-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-B1EOxG1CwVavvI87bW7TY
key:                  hie-bios-0.12.0-B1EOxG1CwVavvI87bW7TY
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  ada5e7badee9f4c8a464a92ee408559d
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-B1EOxG1CwVavvI87bW7TY
depends:
    aeson-2.1.2.1-JZeWX2s1eQL7Ta3HF3w6fW base-4.18.2.1
    base16-bytestring-1.0.2.0-HJCFai38hrd834YANCdq3 bytestring-0.11.5.3
    co-log-core-0.3.2.5-CosvKkPIh8b4ADBAritxXo
    conduit-1.3.6.1-JmvSlylEAqiI8LFhx2lxVp
    conduit-extra-1.3.8-IF1ZquB86eb2RrOex2bqoF
    cryptohash-sha1-0.11.101.0-JGdO1S5Mc1sB4wfXRQdaY2 deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-LWra3MmVE7hIjr4mBFp6lZ
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 prettyprinter-1.7.1-6IACTyjRPms8kgGy0SUdjP
    template-haskell-2.20.0.0 temporary-1.3-D64vl65CCuJL1VfIJwvdvy
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-HX6CmWtGzNSCIQWePfXCFw
    unordered-containers-0.2.20.1-8SON4238u8N3rDHPceHjHx
    yaml-0.11.11.2-CS9jj0skP8B8obc9v5e4bH

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hie-bios-0.12.0-151-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hie-bios.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hie-bios
version:              0.12.0
visibility:           public
id:                   hie-bios-0.12.0-7TE2uPDNeaM5HR2SVUbBXV
key:                  hie-bios-0.12.0-7TE2uPDNeaM5HR2SVUbBXV
license:              BSD-3-Clause
maintainer:           Matthew Pickering <matthewtpickering@gmail.com>
author:               Matthew Pickering <matthewtpickering@gmail.com>
homepage:             https://github.com/mpickering/hie-bios
synopsis:             Set up a GHC API session
description:
    Set up a GHC API session and obtain flags required to compile a source file

category:             Development
abi:                  b429107e6ba26ca85181d2a220e6a50e
exposed:              True
exposed-modules:
    HIE.Bios HIE.Bios.Config HIE.Bios.Config.YAML HIE.Bios.Cradle
    HIE.Bios.Environment HIE.Bios.Flags HIE.Bios.Ghc.Api
    HIE.Bios.Ghc.Check HIE.Bios.Ghc.Doc HIE.Bios.Ghc.Gap
    HIE.Bios.Ghc.Load HIE.Bios.Ghc.Logger HIE.Bios.Internal.Debug
    HIE.Bios.Types HIE.Bios.Wrappers

hidden-modules:       Paths_hie_bios
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hie-bios-0.12.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hie-bios
hs-libraries:         HShie-bios-0.12.0-7TE2uPDNeaM5HR2SVUbBXV
depends:
    aeson-2.1.2.1-6DouAcLayfd1cKsM4PdlxR base-4.18.2.1
    base16-bytestring-1.0.2.0-IBSXo3fNQsx2cpIyb3dUEY
    bytestring-0.11.5.3 co-log-core-0.3.2.5-2ExlOo3oUbZ1DwKj5dQd3r
    conduit-1.3.6.1-IACzArib6WtLejx9Lk1hSM
    conduit-extra-1.3.8-9QiDtjtytfa6eCoLtsLqkJ
    cryptohash-sha1-0.11.101.0-DPSO7HHQYEzERsubsEiwew deepseq-1.4.8.1
    directory-1.3.8.5 exceptions-0.10.7
    extra-1.7.16-8dGAsSrJDrL2Qv7CcA7Z6y
    file-embed-0.0.16.0-6A32wX7iXBC7ZTuLWlLLWz filepath-1.4.300.1
    ghc-9.6.6 prettyprinter-1.7.1-1A9qDzGwN5aD62WFF8DTGH
    template-haskell-2.20.0.0 temporary-1.3-BelDM7zTWCg7tBff187Pbn
    text-2.0.2 time-1.12.2 transformers-0.6.1.0
    unix-compat-0.7.4.1-7Zyia4XRlOQIIQMyLxI1QD
    unordered-containers-0.2.20.1-650icVWmHjf3WKXK0GKpae
    yaml-0.11.11.2-9quCwX1yndE4hP4rvoY2SV

haddock-interfaces:   /usr/share/doc/haskell-hie-bios/html/hie-bios.haddock
haddock-html:         /usr/share/doc/haskell-hie-bios/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
